#include <boot/stivale/stivale.h>
#include <kernel/tty/tty.h>

// We will now write a helper function which will allow us to scan for tags
// that we want FROM the bootloader (structure tags).
void *stivale2_get_tag(struct stivale2_struct *stivale2_struct, uint64_t id) {
    struct stivale2_tag *current_tag = (void *)stivale2_struct->tags;
    for (;;) {
        // If the tag pointer is NULL (end of linked list), we did not find
        // the tag. Return NULL to signal this.
        if (current_tag == NULL) {
            return NULL;
        }

        // Check whether the identifier matches. If it does, return a pointer
        // to the matching tag.
        if (current_tag->identifier == id) {
            return current_tag;
        }

        // Get a pointer to the next tag in the linked list and repeat.
        current_tag = (void *)current_tag->next;
    }
}

struct stivale2_struct_tag_terminal *terminal_tag = NULL;

// stivale function stubs
void (*term_write)(const char *string, size_t length) = NULL;

// for this driver we simply load all the function pointers from the terminal tag
void terminal_initialize() {
    terminal_tag = stivale2_get_tag(stivale2_struct, STIVALE2_STRUCT_TAG_TERMINAL_ID);

    // Check if the tag was actually found.
    if (terminal_tag == NULL) {
        // It wasn't found, just hang...
        for (;;) {
            asm ("hlt");
        }
    }

    // the address from this struct is uint64, so we must convert to a pointer
    term_write = (void *)terminal_tag->term_write;
}

void tty_print(const char* str, int length) {
    term_write(str, length);
}
